@@ -15,7 +15,7 @@
  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
  You can contact the author at:
- https://github.com/traversc/qs
+ https://github.com/qsbase/qs
 */
 
 #include "qs_common.h"
@@ -844,6 +844,13 @@ SEXP get_altrep_class_info(SEXP obj) {
 #endif
 }
 
+// [[Rcpp::export(rng = false)]]
+bool set_trust_promises(bool value) {
+  bool previous_value = trust_promises_global;
+  trust_promises_global = value;
+  return previous_value;
+}
+
 
 // std::vector<unsigned char> brotli_compress_raw(RawVector x, int compress_level) {
 //   uint64_t zsize = BrotliEncoderMaxCompressedSize(x.size());
